#
# spec file for package guvcview
#
# Copyright (c) 2012 Malcolm J Lewis <malcolmlewis@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define         soname 1_0-0

Name:           guvcview
Version:        2.0.1
Release:        1.2
License:        GPL-3.0
# Reference to GPL-2.0 in some files?
Summary:        GTK+ UVC Viewer and Capturer
Url:            http://guvcview.sourceforge.net/
Group:          Productivity/Multimedia/Video/Players
Source0:        http://sourceforge.net/projects/guvcview/files/source/guvcview-src-%{version}.tar.gz
Patch0:         guvcview-no-return-in-nonvoid-function.patch
Patch1:         guvcview-implicit-pointer-decl.patch
Patch2:         guvcview-voidreturn.patch
BuildRequires:  libSDL2-devel
BuildRequires:  gsl-devel
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  libffmpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  libusb-1_0-devel
BuildRequires:  libudev-devel
BuildRequires:  libv4l-devel
BuildRequires:  glibc-devel
BuildRequires:  portaudio-devel
BuildRequires:  alsa-devel
BuildRequires:  update-desktop-files
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package -n libgviewaudio-%{soname}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries

%description -n libgviewaudio-%{soname}
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package -n libgviewencoder-%{soname}
Summary:        GTK+ UVC Viewer and Capturer
Group:          ystem/Libraries

%description -n libgviewencoder-%{soname}
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package -n libgviewrender-%{soname}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries

%description -n libgviewrender-%{soname}
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package -n libgviewv4l2core-%{soname}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries

%description -n libgviewv4l2core-%{soname}
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package devel
Summary:        GTK+ UVC Viewer and Capturer
Group:          Development/Libraries/C and C++
Requires:       libgviewaudio-%{soname} = %{version}-%{release}
Requires:       libgviewencoder-%{soname} = %{version}-%{release}
Requires:       libgviewrender-%{soname} = %{version}-%{release}
Requires:       libgviewv4l2core-%{soname} = %{version}-%{release}
Requires:       portaudio-devel
Requires:       alsa-devel
Requires:       glibc-devel
Requires:       libpulse-devel
Requires:       libffmpeg-devel
Requires:       gsl-devel
Requires:       libSDL2-devel
Requires:       libv4l-devel
Requires:       libudev-devel
Requires:       libusb-1_0-devel
Requires:       libpng-devel

%description devel
A simple GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%lang_package

%prep
%setup -q -n %{name}-src-%{version}
%patch0
%patch1
%patch2
chmod -x ChangeLog

%build
CPPFLAGS=-I/usr/include/ffmpeg
export CPPFLAGS
%configure --disable-debian-menu \
	   --disable-desktop
make %{?_smp_mflags}

%install
%make_install
# Remove installed documentation
pushd %{buildroot}%{_datadir}/doc
rm -rf %{name}
popd
# Create desktop file as disabled during build
%suse_update_desktop_file -c %{name} "A video viewer and capturer for the linux uvc driver" %{name} %{name} %{name} AudioVideo AudioVideoEditing
pushd %{buildroot}%{_datadir}/pixmaps
cp %{name}/%{name}.png .
popd
%find_lang %{name} %{?no_lang_C}
%find_lang gview_v4l2core %{name}.lang %{?no_lang_C}
%fdupes %{buildroot}

rm -f %{buildroot}%{_libdir}/*.{la,a}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post
%endif

%if 0%{?suse_version} > 1130
%postun
%desktop_database_postun
%endif

%post -n libgviewaudio-%{soname} -p /sbin/ldconfig
%postun -n libgviewaudio-%{soname} -p /sbin/ldconfig

%post -n libgviewencoder-%{soname} -p /sbin/ldconfig
%postun -n libgviewencoder-%{soname} -p /sbin/ldconfig

%post -n libgviewrender-%{soname} -p /sbin/ldconfig
%postun -n libgviewrender-%{soname} -p /sbin/ldconfig

%post -n libgviewv4l2core-%{soname} -p /sbin/ldconfig
%postun -n libgviewv4l2core-%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING README.md
%{_bindir}/%{name}
%dir %{_datadir}/pixmaps/%{name}
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/pixmaps/%{name}/*.png
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/*.gz

%files -n libgviewaudio-%{soname}
%defattr(-,root,root)
%{_libdir}/libgviewaudio-1.0.so.0
%{_libdir}/libgviewaudio-1.0.so.0.1.0

%files -n libgviewencoder-%{soname}
%defattr(-,root,root)
%{_libdir}/libgviewencoder-1.0.so.0
%{_libdir}/libgviewencoder-1.0.so.0.1.0

%files -n libgviewrender-%{soname}
%defattr(-,root,root)
%{_libdir}/libgviewrender-1.0.so.0
%{_libdir}/libgviewrender-1.0.so.0.1.0

%files -n libgviewv4l2core-%{soname}
%defattr(-,root,root)
%{_libdir}/libgviewv4l2core-1.0.so.0
%{_libdir}/libgviewv4l2core-1.0.so.0.1.0

%files devel
%defattr(-,root,root)
%dir %{_includedir}/guvcview-2
%dir %{_includedir}/guvcview-2/libgviewaudio
%dir %{_includedir}/guvcview-2/libgviewencoder
%dir %{_includedir}/guvcview-2/libgviewrender
%dir %{_includedir}/guvcview-2/libgviewv4l2core
%{_includedir}/guvcview-2/libgviewaudio/gviewaudio.h
%{_includedir}/guvcview-2/libgviewencoder/gviewencoder.h
%{_includedir}/guvcview-2/libgviewrender/gviewrender.h
%{_includedir}/guvcview-2/libgviewv4l2core/gview.h
%{_includedir}/guvcview-2/libgviewv4l2core/gviewv4l2core.h
%{_libdir}/libgviewaudio.so
%{_libdir}/libgviewencoder.so
%{_libdir}/libgviewrender.so
%{_libdir}/libgviewv4l2core.so
%{_libdir}/pkgconfig/libgviewaudio.pc
%{_libdir}/pkgconfig/libgviewencoder.pc
%{_libdir}/pkgconfig/libgviewrender.pc
%{_libdir}/pkgconfig/libgviewv4l2core.pc

%files lang -f %{name}.lang

%changelog
* Fri Oct 31 2014 joerg.lorenzen@ki.tng.de
- Update to version 2.0.1:
  + Fix audio clean bug (segfault when audio=none).
  + Add --disable_libv4l2 option.
  + Add support for internal yu12 planar format.
  + Workaround uvcvideo bug (buf.bytesused=0 on kernels >=3.16).
- Changes since version 2.0.0:
  + New version 2.0.0 (code rewriten from scratch).
  + Move all core functions to 4 shared libs.
  + Change options.
  + Change config.
  + Add sdl2 render.
  + Use gsl for random number generation.
- Changes since version 1.7.3:
  + Add silence frames to compensate audio drift (delay).
  + Fix possible memory leak.
  + Add video and image capture through system signals:
    SIGUSR1 and SIGUSR2.
  + Add true no_display mode (no X required).
  + Small bug fixes.
- Changes since version 1.7.2:
  + Add H264 decoding support.
  + Sync translations.
- Changes since version 1.7.1:
  + Fix avi muxer: fix opendml indexes (>= 1Gb).
  + Update Italian translation.
* Tue Jul 30 2013 i@margueirte.su
- build against libffmpeg-devel.
* Sat Jul 20 2013 zaitor@opensuse.org
- Update to version 1.7.0:
  + Refactor avi muxer (base it on libav muxer with opendml
    support).
  + Refactor mkv muxer (base it on libav muxer with webm support).
  + Add VP8, Theora and Vorbis codecs.
  + Add Webm support.
  + Add a Top Menu.
  + Move all file operations to the Top Menu.
* Thu Sep 20 2012 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix build with latest libavcodec.
  + Fix audio codecs listing.
  + Fix audio codecs (AC3 and AAC) input format for latest
    libavcodec API (float).
  + Add support for delayed frames in video encoding.
- Changes since version 1.6.0:
  + Run audio in separate thread.
  + Update audio buffer.
  + Move pulse audio interface from simple to async API.
  + Add pulse device list.
  + Enable build of pulse API by default.
- Added new build dependency, intltool.
* Sun May 20 2012 zaitor@opensuse.org
- Update to version 1.5.3:
  + Update libavcodec API.
  + Add libavutil dependency.
  + Fix pulse interface.
  + Update language catalogs.
- Drop guvcview-pulseaudio-fix.patch, fixed upstream.
- Change BuildRequires: pulseaudio-devel to libpulse-devel.
* Sun Feb 26 2012 zaitor@opensuse.org
- Update to version 1.5.2:
  + Move to pthreads (fix gthread API 2 issues).
  + Add italian translation.
  + Fix several libavcodec issues.
  + Fix some gtk3 widgets.
- Drop guvcview-fix-glib-include.patch, fixed upstream.
- Add guvcview-pulseaudio-fix.patch: Fix pulseaudio interface.
* Mon Jan 23 2012 malcolmlewis@opensuse.org
- Updated to version 1.5.1:
  + Moved to gtk3.
  + Make control window size dependent on screen resolution.
  + Threaded coding patch - George Sedov <radist.morse@gmail.com>.
  + Fix h264 codec properties.
- Updates from version 1.5.0:
  + Add a no display mode (--no_display).
  + Fix build issues with newer versions (>=0.7.x) of ffmpeg
    libavcodec.
  + Add support for unix signals.
  + Add VU meter OSD.
  + Fix menu controls (linux 3.0).
- Add guvcview-fix-glib-include.patch: To fix only <glib.h> can be
  included directly error for builds > 1210.
* Mon Oct  3 2011 malcolmlewis@opensuse.org
- Fix guvcview.desktop file in spec file.
* Fri Jul  1 2011 malcolmlewis@opensuse.org
- Initial build based on fc15 spec file.
